pub struct Patch<'doc> {
pub route: Route<'doc>,
pub operation: Op<'doc>,
}Expand description
Represents a single YAML patch.
A patch operation consists of a route to the feature to patch and the operation to perform on that feature.
Fields
route: Route<'doc>The route to the feature to patch.
operation: Op<'doc>The operation to perform on the feature.